@@ -12,12 +12,11 @@ import Data.Attoparsec.Lazy (parse, maybeResult)
 import qualified Data.HashMap.Lazy as Map
 import Data.Text.Encoding (encodeUtf8)
 import Control.Monad.IO.Class (liftIO)
-import Control.Monad.Trans.Control (MonadBaseControl)
-import Control.Monad.Trans.Resource (MonadResource)
+import Data.Conduit (MonadBaseControl, MonadResource)
 
 -- | Location of the Javascript file hosted by browserid.org
 browserIdJs :: Text
-browserIdJs = "https://browserid.org/include.js"
+browserIdJs = "https://login.persona.org/include.js"
 
 checkAssertion :: (MonadResource m, MonadBaseControl IO m)
                => Text -- ^ audience
@@ -25,7 +24,7 @@ checkAssertion :: (MonadResource m, MonadBaseControl IO m)
                -> Manager
                -> m (Maybe Text)
 checkAssertion audience assertion manager = do
-    req' <- liftIO $ parseUrl "https://browserid.org/verify"
+    req' <- liftIO $ parseUrl "https://verifier.login.persona.org/verify"
     let req = urlEncodedBody
                 [ ("audience", encodeUtf8 audience)
                 , ("assertion", encodeUtf8 assertion)
